@@ -377,6 +377,17 @@ RCT_EXPORT_METHOD(createNewSession:(NSString *)trackerId screenName:(NSString *)
     [tracker send:[builder build]];
 }
 
+RCT_EXPORT_METHOD(dispatch:(RCTPromiseResolveBlock)resolve
+                  reject:(RCTPromiseRejectBlock)reject) {
+    [[GAI sharedInstance] dispatchWithCompletionHandler:^void(GAIDispatchResult result){
+        if (result != kGAIDispatchError) {
+            resolve(@YES);
+        } else {
+            reject(@"DISPATCH_FAILED", nil, RCTErrorWithMessage(@"Dispatch failed"));
+        }
+    }];
+}
+
 + (BOOL)requiresMainQueueSetup
 {
     return YES;
